Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(177)

Unified Diff: chrome/browser/sync/sync_setup_wizard.h

Issue 3655004: Add UI for setting the encryption passphrase.... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: fixes Created 10 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/sync/sync_setup_flow.cc ('k') | chrome/browser/sync/sync_setup_wizard.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/sync/sync_setup_wizard.h
===================================================================
--- chrome/browser/sync/sync_setup_wizard.h (revision 62207)
+++ chrome/browser/sync/sync_setup_wizard.h (working copy)
@@ -21,23 +21,26 @@
// A login attempt succeeded. This will wait for an explicit transition
// (via Step) to the next state.
GAIA_SUCCESS,
- // Show the screen that lets you click either "Keep everything synced" or
- // "Choose which data types to sync", and checkboxes for each data type.
- CHOOSE_DATA_TYPES,
- // Show the screen that lets you create a passphrase (if you've never set
- // one up before).
+ // Show the screen that lets you configure sync.
+ // There are two tabs:
+ // Data Types --
+ // Choose either "Keep everything synced" or
+ // "Choose which data types to sync", and checkboxes for each data type.
+ // Encryption --
+ // Choose what to encrypt and whether to use a passphrase.
+ CONFIGURE,
+ // Show the screen that lets you enter a new passphrase
CREATE_PASSPHRASE,
- // Show the screen that lets you enter the passphrase (if you've set one up
- // on another machine).
+ // Show the screen that prompts for your passphrase
ENTER_PASSPHRASE,
- // Show the screen that lets you reset your passphrase (if you forgot it).
- RESET_PASSPHRASE,
// The panic switch. Something went terribly wrong during setup and we
// can't recover.
FATAL_ERROR,
// The client can't set up sync at the moment due to a concurrent operation
// to clear cloud data being in progress on the server.
SETUP_ABORTED_BY_PENDING_CLEAR,
+ // Loading screen with spinny throbber.
+ SETTING_UP,
// A final state for when setup completes and it is possible it is the
// user's first time (globally speaking) as the cloud doesn't have any
// bookmarks. We show additional info in this case to explain setting up
« no previous file with comments | « chrome/browser/sync/sync_setup_flow.cc ('k') | chrome/browser/sync/sync_setup_wizard.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698